@@ -9,7 +9,7 @@
   attr(.hm_cache$star_cache,"map") <- "" # no map name yet
 
   requireNamespace("s2", quietly = TRUE)
-  sf::sf_use_s2(TRUE) # is this rude - changing a state silently?
+  invisible(utils::capture.output(sf::sf_use_s2(TRUE))) # is this rude - changing a state silently?
 
   requireNamespace("data.table", quietly = TRUE)
 }
