@@ -1,9 +1,7 @@
-library(dplyr)
-library(sf)
 
 test_that("Default aircraft data loads", {
-  expect_warning(make_aircraft())
-  expect_known_value(make_aircraft(warn = FALSE), "known/ac_default_load")
+  expect_warning(z <- make_aircraft())
+  expect_snapshot_value(z, style = "serialize")
 })
 
 test_that("Aircraft data loads", {
@@ -11,7 +9,7 @@ test_that("Aircraft data loads", {
                    over_sea_M = 2.0, over_land_M = 0.9, accel_Mpm = 0.2,
                    arrdep_kph = 300, range_km = 6000, stringsAsFactors=FALSE)
   # it was with 2+ rows that this failed, so test that
-  expect_known_value(make_aircraft(rbind(ac, ac)), "known/ac_load")
+  expect_snapshot_value(make_aircraft(rbind(ac, ac)), style = "serialize")
   #missing vbl
   ac <- data.frame(id = "test", type = "test aircraft",
                    over_sea_M = 2.0, over_land_M = 0.9,
@@ -27,19 +25,19 @@ test_that("Aircraft data loads", {
 
 test_that("Default airport data loads", {
   # strip wkt using st_coordinates
-  expect_message(z <- make_airports() %>%
-                   filter(APICAO == "EGLL") %>%
-                   mutate(ap_locs = sf::st_coordinates(ap_locs)))
-  expect_known_value(z, "known/default_airport_EGLL")
+  expect_message(z <- make_airports() |>
+                   dplyr::filter(APICAO == "EGLL") |>
+                   dplyr::mutate(ap_locs = sf::st_coordinates(ap_locs)))
+  expect_snapshot_value(z, style = "serialize")
 })
 
 test_that("Airport data loads", {
   # normal functioning
   airports <- data.frame(APICAO = c("TEST", "test2"), lat = c(10, 5),
-                         long = c(10, -5), stringsAsFactors = FALSE) %>%
-    make_airports() %>%
-    mutate(ap_locs = sf::st_coordinates(ap_locs))
-  expect_known_value(airports, "known/TEST_airport")
+                         long = c(10, -5), stringsAsFactors = FALSE) |>
+    make_airports() |>
+    dplyr::mutate(ap_locs = sf::st_coordinates(ap_locs))
+  expect_snapshot_value(airports, style = "serialize")
 
   # with missing variable
   airports_miss <- data.frame(APICAO = "TEST", lat = 10, stringsAsFactors = FALSE)
@@ -63,19 +61,19 @@ test_that("NZ maps available", {
   NZ_coast <- hm_get_test("coast")
   NZ_buffer30 <- hm_get_test("buffer")
 
-  expect_true(all(st_is(NZ_coast, c("POLYGON", "MULTIPOLYGON"))))
-  expect_true(all(st_is(NZ_buffer30, c("POLYGON", "MULTIPOLYGON"))))
+  expect_true(all(sf::st_is(NZ_coast, c("POLYGON", "MULTIPOLYGON"))))
+  expect_true(all(sf::st_is(NZ_buffer30, c("POLYGON", "MULTIPOLYGON"))))
 })
 
 test_that("can make AP2",{
-  z <- make_AP2("EGLL","NZCH")
+  aps <- make_airports(warn = FALSE)
+  z <- make_AP2("EGLL","NZCH", ap = aps)
   expect_equal(z$AP2, "EGLL<>NZCH")
   expect_equal(signif(z$gcdist_km,3), 19000)
   #don't mind which order they're in
   expect_setequal(round(z[1,c("from_long", "to_long")],2),
                   c(-0.46, 172.53))
-  aps <- make_airports()
-  z <- make_AP2("BIKF", "EDDF")
+  z <- make_AP2("BIKF", "EDDF", ap = aps)
   #check sort order
   expect_equal(z$AP2, "EDDF<>BIKF")
   expect_error(make_AP2("EGLL","ZZZZ", aps), "unknown")
